OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "A „config” könyvtár nem írható.",
    "This can usually be fixed by giving the web server write access to the config directory." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a konfigurációs könyvtáron.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "De ha szeretné, hogy a config.php fájlja csak olvasható legyen, akkor állítsa benne igazra a „config_is_read_only” beállítást.",
    "See %s" : "Lásd %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "A(z) %1$s alkalmazás fájljait helytelenül cserélték le. Ellenőrizze, hogy a verzió kompatibilis-e a kiszolgálóval.",
    "Sample configuration detected" : "Példabeállítások észlelve",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik, hogy a példakonfigurációt másolta le. Ez működésképtelenné teheti a telepítést, és nem támogatott. Olvassa el a dokumentációt, mielőtt módosításokat véget a config.php fájlban.",
    "404" : "404",
    "The page could not be found on the server." : "Az oldal nem található a kiszolgálón.",
    "%s email verification" : "%s e-mail ellenőrzés",
    "Email verification" : "E-mail ellenőrzés",
    "Click the following button to confirm your email." : "Kattintson a következő gombra, hogy megerősítse az e-mail-címét.",
    "Click the following link to confirm your email." : "Kattintson a következő hivatkozásra, hogy megerősítse az e-mail-címét.",
    "Confirm your email" : "E-mail-cím megerősítése",
    "Other activities" : "Egyéb tevékenységek",
    "%1$s and %2$s" : "%1$s és %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s és %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s és %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s és %5$s",
    "Education Edition" : "Oktatási kiadás",
    "Enterprise bundle" : "Vállalati csomag",
    "Groupware bundle" : "Csoportmunka csomag",
    "Hub bundle" : "Központi csomag",
    "Social sharing bundle" : "Közösségi megosztás csomag",
    "PHP %s or higher is required." : "PHP %s vagy újabb szükséges.",
    "PHP with a version lower than %s is required." : "Ennél régebbi PHP verzió szükséges: %s.",
    "%sbit or higher PHP required." : "%s bites vagy újabb PHP szükséges.",
    "The following architectures are supported: %s" : "A következő architektúrák támogatottak: %s",
    "The following databases are supported: %s" : "A következő adatbázisok támogatottak: %s",
    "The command line tool %s could not be found" : "A parancssori eszköz nem található: %s",
    "The library %s is not available." : "A(z) %s programkönyvtár nem érhető el.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "A(z) %1$s programkönyvtár %2$s vagy újabb verziója szükséges – elérhető verzió: %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "A(z) %1$s programkönyvtár %2$s vagy régebbi verziója szükséges – elérhető verzió: %3$s.",
    "The following platforms are supported: %s" : "A következő platformok támogatottak: %s",
    "Server version %s or higher is required." : "%s vagy újabb kiszolgálóverzió szükséges.",
    "Server version %s or lower is required." : "%s vagy régebbi kiszolgálóverzió szükséges.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazdának kell lennie, vagy speciális hozzáféréssel kell rendelkeznie ehhez a beállításhoz",
    "Logged in user must be an admin or sub admin" : "A bejelentkezett felhasználónak rendszergazdának vagy alrendszergazgának kell lennie",
    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
    "Wiping of device %s has started" : "A(z) %s eszköz törlése megkezdődött",
    "Wiping of device »%s« has started" : "A(z) „%s” eszköz törlése megkezdődött",
    "»%s« started remote wipe" : "„%s” elindította a távoli törlést",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "A(z) „%s” eszköz vagy alkalmazás elindította a távoli törlési folyamatot. A folyamat befejezése után újabb e-mailt fog kapni.",
    "Wiping of device %s has finished" : "A(z) %s eszköz törlése befejeződött",
    "Wiping of device »%s« has finished" : "A(z) „%s” eszköz törlése befejeződött",
    "»%s« finished remote wipe" : "A(z) „%s” befejezte a távoli törlést",
    "Device or application »%s« has finished the remote wipe process." : "A(z) „%s” eszköz vagy alkalmazás befejezte a távoli törlés folyamatát.",
    "Remote wipe started" : "A távoli törlés elindult",
    "A remote wipe was started on device %s" : "Távoli törlés indult a(z) %s eszközön",
    "Remote wipe finished" : "A távoli törlés befejeződött",
    "The remote wipe on %s has finished" : "A(z) %s távoli törlése befejeződött",
    "Authentication" : "Hitelesítés",
    "Unknown filetype" : "Ismeretlen fájltípus",
    "Invalid image" : "Érvénytelen kép",
    "Avatar image is not square" : "A profilkép nem négyzetes.",
    "Files" : "Fájlok",
    "View profile" : "Profil megtekintése",
    "Local time: %s" : "Helyi idő: %s",
    "today" : "ma",
    "tomorrow" : "holnap",
    "yesterday" : "tegnap",
    "_in %n day_::_in %n days_" : ["%n napon belül","%n napon belül"],
    "_%n day ago_::_%n days ago_" : ["%n napja","%n napja"],
    "next month" : "jövő hónapban",
    "last month" : "múlt hónapban",
    "_in %n month_::_in %n months_" : ["%n hónapon belül","%n hónapon belül"],
    "_%n month ago_::_%n months ago_" : ["%n hónapja","%n hónapja"],
    "next year" : "jövőre",
    "last year" : "tavaly",
    "_in %n year_::_in %n years_" : ["%n éven belül","%n éven belül"],
    "_%n year ago_::_%n years ago_" : ["%n éve","%n éve"],
    "_in %n hour_::_in %n hours_" : ["%n órán belül","%n órán belül"],
    "_%n hour ago_::_%n hours ago_" : ["%n órája","%n órája"],
    "_in %n minute_::_in %n minutes_" : ["%n percen belül","%n percen belül"],
    "_%n minute ago_::_%n minutes ago_" : ["%n perce","%n perce"],
    "in a few seconds" : "pár másodpercen belül",
    "seconds ago" : "pár másodperce",
    "Empty file" : "Üres fájl",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "A(z) %s azonosítójú modul nem létezik. Engedélyezze az alkalmazásbeállításokban, vagy lépjen kapcsolatba a rendszergazdával.",
    "File already exists" : "A fájl már létezik",
    "Invalid path" : "Érvénytelen útvonal",
    "Failed to create file from template" : "Nem sikerült létrehozni a fájlt a sablonból",
    "Templates" : "Sablonok",
    "File name is a reserved word" : "A fájl neve egy fenntartott szó",
    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz",
    "File name is too long" : "A fájlnév túl hosszú",
    "Dot files are not allowed" : "A ponttal kezdődő fájlok nem engedélyezettek",
    "Empty filename is not allowed" : "Az üres fájlnév nem engedélyezett",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert az appinfo fájl nem olvasható.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A(z) „%s” alkalmazást nem lehet telepíteni, mert nem kompatibilis ezzel a kiszolgálóverzióval.",
    "__language_name__" : "Magyar",
    "This is an automatically sent email, please do not reply." : "Ez egy automatikusan küldött levél, ne válaszoljon rá.",
    "Help" : "Súgó",
    "Appearance and accessibility" : "Megjelenés és akadálymentesítés",
    "Apps" : "Alkalmazások",
    "Personal settings" : "Személyes beállítások",
    "Administration settings" : "Rendszergazdai beállítások",
    "Settings" : "Beállítások",
    "Log out" : "Kijelentkezés",
    "Users" : "Felhasználók",
    "Email" : "E-mail",
    "Mail %s" : "Levél küldése ide: %s",
    "Fediverse" : "Födiverzum",
    "View %s on the fediverse" : "A(z) %s megtekintése a födiverzumban",
    "Phone" : "Telefon",
    "Call %s" : "%s hívása",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "%s megtekintése a Twittere",
    "Website" : "Weboldal",
    "Visit %s" : "%s felkeresése",
    "Address" : "Cím",
    "Profile picture" : "Profilkép",
    "About" : "Névjegy",
    "Display name" : "Megjelenítendő név",
    "Headline" : "Címsor",
    "Organisation" : "Szervezet",
    "Role" : "Szerepkör",
    "Unknown user" : "Ismeretlen felhasználó",
    "Additional settings" : "További beállítások",
    "Enter the database username and name for %s" : "Adja meg a %s adatbázisának nevét és a hozzá tartozó felhasználónevet",
    "Enter the database username for %s" : "Adja meg a %s adatbázisához tartozó felhasználónevet",
    "Enter the database name for %s" : "Adja meg a %s adatbázisának nevét",
    "You cannot use dots in the database name %s" : "A(z) %s adatbázisnév nem tartalmazhat pontot",
    "MySQL username and/or password not valid" : "A MySQL felhasználónév vagy jelszó érvénytelen",
    "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnia.",
    "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
    "Oracle username and/or password not valid" : "Az Oracle felhasználónév vagy jelszó érvénytelen",
    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név vagy jelszó érvénytelen",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott, és a %s nem lesz teljesen működőképes. Csak saját felelősségre használja.",
    "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux kiszolgálót használni.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32 bites PHP környezetben fut, és az open_basedir be lett állítva a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat, így erősen ellenjavallott.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Távolítsa el az open_basedir beállítást a php.ini fájlból, vagy váltson 64 bites PHP-ra.",
    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet.",
    "Set an admin password." : "Állítson be egy rendszergazdai jelszót.",
    "Cannot create or write into the data directory %s" : "Nem létre létrehozni vagy beleírni a(z) %s adatkönyvtárba",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A(z) %s megosztási alrendszernek meg kell valósítania az OCP\\Share_Backend interfészt",
    "Sharing backend %s not found" : "A(z) %s megosztási alrendszer nem található",
    "Sharing backend for %s not found" : "A(z) %s megosztási alrendszere nem található",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta Önnel: „%2$s”, és hozzá akarja adni",
    "»%s« added a note to a file shared with you" : "„%s” megjegyzést fűzött az Önnel megosztott fájlhoz",
    "Open »%s«" : "A(z) „%s” megnyitása",
    "%1$s via %2$s" : "%1$s – %2$s",
    "You are not allowed to share %s" : "Nincs jogosultsága a(z) %s megosztásához",
    "Cannot increase permissions of %s" : "A(z) %s engedélyei nem bővíthetők",
    "Files cannot be shared with delete permissions" : "A fájlok nem oszthatók meg törlési jogosultsággal",
    "Files cannot be shared with create permissions" : "A fájlok nem oszthatók meg létrehozási jogosultsággal",
    "Expiration date is in the past" : "A lejárati dátum már elmúlt",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nem állítható be %n napnál távolabbi lejárati dátum","Nem állítható be %n napnál távolabbi lejárati dátum"],
    "Sharing is only allowed with group members" : "A megosztás csak a csoport tagjaival engedélyezett",
    "Sharing %s failed, because this item is already shared with user %s" : "A(z) %s megosztása nem sikerült, mert ez az elem már meg van osztva a(z) %s felhasználóval",
    "%1$s shared »%2$s« with you" : "%1$s megosztotta Önnel: „%2$s”",
    "%1$s shared »%2$s« with you." : "%1$s megosztotta Önnel: „%2$s”.",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
    "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "A felhasználó nem jött létre, mert elérte a felhasználókorlátot. Nézze meg az értesítéseit, hogy többet tudjon meg.",
    "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
    "Sunday" : "Vasárnap",
    "Monday" : "Hétfő",
    "Tuesday" : "Kedd",
    "Wednesday" : "Szerda",
    "Thursday" : "Csütörtök",
    "Friday" : "Péntek",
    "Saturday" : "Szombat",
    "Sun." : "Vas.",
    "Mon." : "Hé.",
    "Tue." : "Ke.",
    "Wed." : "Sze.",
    "Thu." : "Csü.",
    "Fri." : "Pén.",
    "Sat." : "Szo.",
    "Su" : "Va",
    "Mo" : "Hé",
    "Tu" : "Ke",
    "We" : "Sze",
    "Th" : "Cs",
    "Fr" : "Pé",
    "Sa" : "Szo",
    "January" : "Január",
    "February" : "Február",
    "March" : "Március",
    "April" : "Április",
    "May" : "Május",
    "June" : "Június",
    "July" : "Július",
    "August" : "Augusztus",
    "September" : "Szeptember",
    "October" : "Október",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Már.",
    "Apr." : "Ápr.",
    "May." : "Máj.",
    "Jun." : "Jún.",
    "Jul." : "Júl.",
    "Aug." : "Aug.",
    "Sep." : "Szep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Érvényes jelszót kell megadnia",
    "The username is already being used" : "Ez a felhasználónév már foglalt",
    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, szóköz és „_.@-'”",
    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
    "Username is invalid because files already exist for this user" : "A felhasználónév érvénytelen, mert már vannak fájlok ehhez a felhasználóhoz",
    "User disabled" : "Felhasználó letiltva",
    "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "A(z) „%1$s” alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
    "a safe home for all your data" : "egy biztonságos hely az adataidnak",
    "File is currently busy, please try again later" : "A fájl jelenleg foglalt, próbálja újra később",
    "Cannot download file" : "A fájl nem tölthető le",
    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
    "Authentication error" : "Hitelesítési hiba",
    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
    "Cannot write into \"config\" directory." : "A „config” könyvtár nem írható.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a config könyvtáron. Lásd %s.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Vagy, ha jobbnak látja, hogy a config.php fájl csak olvasható legyen, akkor állítsa igazra a „config_is_read_only” beállítást. Lásd: %s.",
    "Cannot write into \"apps\" directory." : "Az „apps” könyvtár nem írható.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára az apps könyvtáron, vagy letiltja az alkalmazástárt a konfigurációs fájlban.",
    "Cannot create \"data\" directory." : "A „data” könyvtár nem hozható létre.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ez általában úgy javítható, hogy írási jogosultságot ad a webkiszolgáló számára a gyökérkönyvtáron. Lásd %s.",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Az engedélyek általában úgy javíthatók, hogy írási jogosultságot ad a webkiszolgáló számára a gyökérkönyvtáron. Lásd %s.",
    "Your data directory is not writable." : "Az adatkönyvtár nem írható.",
    "Setting locale to %s failed." : "A területi beállítás „%s” értékre állítása sikertelen.",
    "Please install one of these locales on your system and restart your web server." : "Telepítse a következő területi beállítások valamelyikét a rendszeren, és indítsa újra a webkiszolgálót.",
    "PHP module %s not installed." : "A(z) %s PHP modul nincs telepítve.",
    "Please ask your server administrator to install the module." : "Kérje meg a rendszergazdát, hogy telepítse a modult.",
    "PHP setting \"%s\" is not set to \"%s\"." : "A(z) %s PHP beállítás nincs erre állítva: „%s”.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "A beállítás a php.ini fájlban történő módosításai után újra fog futni a Nexcloud",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Az <code>mbstring.func_overload</code> a várt <code>0</code> érték helyett erre van állítva: <code>%s</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "A probléma javításához állítsa <code>0</code>-ra az <code>mbstring.func_overload</code> értékét a php.ini-ben.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Legalább libxml2 2.7.0 szükséges. Jelenleg telepített: %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "A probléma javításához frissítse a libxml2 verziót, és indítsa újra a webkiszolgálót.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár, mint például a Zend, az OPcache vagy az eAccelererator okozza.",
    "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsem szerepelnek?",
    "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webkiszolgálót.",
    "The required %s config variable is not configured in the config.php file." : "A szükséges %s konfigurációs változó nincs beállítva a config.php fájlban.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Kérje meg a rendszergazdát, hogy ellenőrizze a Nextcloud konfigurációját.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 szükséges.",
    "Please upgrade your database version." : "Frissítse az adatbázis verzióját.",
    "Your data directory is readable by other users." : "Az adatkönyvtára más felhasználók által is olvasható.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználók ne listázhassák.",
    "Your data directory must be an absolute path." : "Az adatkönyvtárnak abszolút útvonalnak kell lennie",
    "Check the value of \"datadirectory\" in your configuration." : "Ellenőrizze a „datadirectory” értékét a konfigurációban.",
    "Your data directory is invalid." : "Az adatkönyvtár érvénytelen.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződjön meg róla, hogy az adatmappa gyökerében van-e egy „.ocdata” fájl.",
    "Action \"%s\" not supported or implemented." : "A(z) „%s” művelet nem támogatott vagy nem ismert.",
    "Authentication failed, wrong token or provider ID given" : "Hitelesítés sikertelen, hibás token vagy szolgáltatóazonosító lett megadva",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "A következő paraméterek hiányoznak, hogy végrehajtható legyen a kérés. Paraméterek: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "A(z) „%1$s” azonosítót már használja a(z) „%2$s” felhős föderációszolgáltató",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "A(z) „%s” azonosító nem létezik a Felhő föderációszolgáltatónal.",
    "Could not obtain lock type %d on \"%s\"." : "Nem sikerült %d típusú zárolást elérni itt: „%s”.",
    "Storage unauthorized. %s" : "A tárolóhoz nincs jogosultság. %s",
    "Storage incomplete configuration. %s" : "A tároló beállítása nem teljes. %s",
    "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
    "Storage connection timeout. %s" : "Időtúllépés a tárolókapcsolatban. %s",
    "Full name" : "Teljes név",
    "%s enter the database username and name." : "%s adja meg az adatbázis nevét és a felhasználónevet.",
    "%s enter the database username." : "%s adja meg az adatbázishoz tartozó felhasználónevet.",
    "%s enter the database name." : "%s adja meg az adatbázis nevét.",
    "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Elérte a felhasználókorlátot, és a felhasználó nem jött létre. Nézze meg az értesítéseit, hogy többet tudjon meg.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: „a-z”, „A-Z”, „0-9”, és „_.@-'”"
},
"nplurals=2; plural=(n != 1);");
